==> tinyerp-server_3.4.2.orig.tar.gz: tinyerp-server-3.4.2/bin/addons/account/wizard/wizard_aged_trial_balance.py <==
##############################################################################
#
# Copyright (c) 2005-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#                    Fabien Pinckaers <fp@tiny.Be>
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import wizard
import time
import datetime

from mx.DateTime import *

_aged_trial_form = """<?xml version="1.0"?>
<form string="Aged Trial Balance">
	<field name="period_length"/>
</form>"""

_aged_trial_fields = {
	'period_length': {'string': 'Period length (days)', 'type': 'integer', 'required': True, 'default': lambda *a:30},
}

def _calc_dates(self, cr, uid, data, context):
	res = {}
	period_length = data['form']['period_length']
	if period_length<=0:
		raise wizard.except_wizard('UserError', 'You must enter a period length that cannot be 0 or below !')
	start = now()
	for i in range(5)[::-1]:
		stop = start-RelativeDateTime(days=period_length)
		res[str(i)] = {
			'name' : 'from %s to %s' % (start.strftime('%Y-%m-%d'), stop.strftime('%Y-%m-%d')),
			'stop': start.strftime('%Y-%m-%d'),
			'start' : stop.strftime('%Y-%m-%d'),
		}
		start = stop - RelativeDateTime(days=1)
	return res

class wizard_report(wizard.interface):
	states = {
		'init': {
			'actions': [],
			'result': {'type':'form', 'arch':_aged_trial_form, 'fields':_aged_trial_fields, 'state':[('end','Cancel'),('print','Print Aged Trial Balance')]},
		},
		'print': {
			'actions': [_calc_dates],
			'result': {'type':'print', 'report':'account.aged.trial.balance', 'state':'end'},
		},
	}

wizard_report('account.aged.trial.balance')

==> tinyerp-server_4.0.3.orig.tar.gz: tinyerp-server-4.0.3/bin/addons/account/wizard/wizard_aged_trial_balance.py <==
##############################################################################
#
# Copyright (c) 2005-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#                    Fabien Pinckaers <fp@tiny.Be>
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import wizard
import time
import datetime

from mx.DateTime import *

_aged_trial_form = """<?xml version="1.0"?>
<form string="Aged Trial Balance">
	<field name="period_length"/>
</form>"""

_aged_trial_fields = {
	'period_length': {'string': 'Period length (days)', 'type': 'integer', 'required': True, 'default': lambda *a:30},
}

def _calc_dates(self, cr, uid, data, context):
	res = {}
	period_length = data['form']['period_length']
	if period_length<=0:
		raise wizard.except_wizard('UserError', 'You must enter a period length that cannot be 0 or below !')
	start = now()
	for i in range(5)[::-1]:
		stop = start-RelativeDateTime(days=period_length)
		res[str(i)] = {
			'name' : 'over '+str((5-i)*period_length)+' days',
			'stop': start.strftime('%Y-%m-%d'),
			'start' : stop.strftime('%Y-%m-%d'),
		}
		start = stop - RelativeDateTime(days=1)
	return res

class wizard_report(wizard.interface):
	states = {
		'init': {
			'actions': [],
			'result': {'type':'form', 'arch':_aged_trial_form, 'fields':_aged_trial_fields, 'state':[('end','Cancel'),('print','Print Aged Trial Balance')]},
		},
		'print': {
			'actions': [_calc_dates],
			'result': {'type':'print', 'report':'account.aged.trial.balance', 'state':'end'},
		},
	}

wizard_report('account.aged.trial.balance')
